nx.graphic.Topology.SceneMixin - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.graphic.Topology.SceneMixin Class

Module: nx.graphic.Topology

Scene mixin

- Index
- Methods
- Properties

## Item Index

### Methods

- activateScene
- deactivateScene
- registerScene

### Properties

- currentSceneName
- scenes
- scenesMap

## Methods

### `activateScene`

(

- `name`

)

Activate a scene, topology only has one active scene.

#### Parameters:

- `name` String

  Scene name which be passed at registerScene

### `deactivateScene`

()

Deactivate a certain scene

### `registerScene`

(

- `name`
- `inClass`

)

Register a scene to topology

#### Parameters:

- `name` String

  for reference to a certain scene

- `inClass` Object

  <String,Class> A scene class name or a scene class instance, which is subclass of nx.graphic.Topology.Scene

## Properties

### `currentSceneName`

Unknown

Current scene name

### `scenes`

Unknown

### `scenesMap`

Unknown